@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for Rational - Rational number class with overflow detection.
-# Copyright (C) 2012, 2013 Antonio Diaz Diaz.
+# Copyright (C) 2012, 2013, 2014 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute and modify it.
@@ -12,7 +12,7 @@ testdir=`cd "$1" ; pwd`
 RATIONAL="${objdir}"/rational
 framework_failure() { echo "failure in testing framework" ; exit 1 ; }
 
-if [ ! -x "${RATIONAL}" ] ; then
+if [ ! -f "${RATIONAL}" ] || [ ! -x "${RATIONAL}" ] ; then
 	echo "${RATIONAL}: cannot execute"
 	exit 1
 fi
